@@ -39,7 +39,7 @@ setClass("kRp.analysis",
 
 setAs(from="kRp.analysis", to="kRp.tagged", function(from){
 		lang <- from@lang
-		tagged.df <- as.data.frame(from@TT.res[, c("token","tag","lemma","lttr","wclass","desc")])
+		tagged.df <- as.data.frame(from@TT.res[, valid.TT.res.kRp.tagged])
 		retagged.object <- new("kRp.tagged", lang=lang, TT.res=tagged.df)
 		return(retagged.object)
 		}
